#
# spec file for package conmon
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           conmon
Version:        2.0.20
Release:        lp152.4.3.1
Summary:        An OCI container runtime monitor
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/containers/conmon
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  glib2-devel
BuildRequires:  pkgconfig(libsystemd)

%description
Conmon is a monitoring program and communication tool between a
container manager (like podman or CRI-O) and an OCI runtime (like
runc or crun) for a single container.

%prep
%setup -q

%build
%make_build

%install
%make_install PREFIX=%{_prefix}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Wed Jul 29 2020 Sascha Grunert <sgrunert@suse.com>
- Update to v2.0.20 (bsc#1175821)
  - journald: fix logging container name
  - container logging: Implement none driver - "off", "null" or
    "none" all work.
  - ctrl: warn if we fail to unlink
  - Drop fsync calls
  - Reap PIDs before running exit command
  - Fix log path parsing
  - Add --sync option to prevent conmon from double forking
  - Add --no-sync-log option to instruct conmon to not sync the
    logs of the containers upon shutting down. This feature fixes a
    regression where we unconditionally dropped the log sync. It is
    possible the container logs could be corrupted on a sudden
    power-off. If you need container logs to remain in consistent
    state after a sudden shutdown, please update from v2.0.19 to
    v2.0.20
* Wed May 27 2020 Sascha Grunert <sgrunert@suse.com>
- Update to v2.0.17
  - Add option to delay execution of exit command
* Mon May 18 2020 Sascha Grunert <sgrunert@suse.com>
- Update to v2.0.16
  - tty: flush pending data when fd is ready
* Fri Apr  3 2020 Ralf Haferkamp <rhafer@suse.com>
- Enable support for journald logging (bsc#1162432)
* Fri Apr  3 2020 Sascha Grunert <sgrunert@suse.com>
- Update to v2.0.15
  - store status while waiting for pid
* Wed Mar 25 2020 Sascha Grunert <sgrunert@suse.com>
- Update to v2.0.14
  - drop usage of splice(2)
  - avoid hanging on stdin
  - stdio: sometimes quit main loop after io is done
  - ignore sigpipe
* Tue Mar 17 2020 Ralf Haferkamp <rhafer@suse.com>
- Update to v2.0.12
  - oom: fix potential race between verification steps
* Thu Mar  5 2020 Sascha Grunert <sgrunert@suse.com>
- Update to v2.0.11
  - log: reject --log-tag with k8s-file
  - chmod std files pipes
  - adjust score to -1000 to prevent conmon from ever being OOM
    killed
  - container OOM: verify cgroup hasn't been cleaned up before
    reporting OOM
* Fri Feb 21 2020 Ralf Haferkamp <rhafer@suse.com>
- Update to v2.0.10 (bsc#1160460, bsc#1164390, jsc#ECO-1048,
  jsc#SLE-11485, jsc#SLE-11331):
  - journal logging: write to /dev/null instead of -1
* Tue Jan  7 2020 Sascha Grunert <sgrunert@suse.com>
- Add TimedOutMessage to config to share with go code
- Fix format string to limit the size of the string to 10
  characters
* Mon Dec 16 2019 Sascha Grunert <sgrunert@suse.com>
- Persist oom files on cgroup v2
- Revert the check for  the OOM counter on cgroups v1 before
  writing OOM file
* Fri Dec 13 2019 Sascha Grunert <sgrunert@suse.com>
- Add --persist-dir flag to allow important container files to be
  written to a persistent directory
- Check OOM counter on cgroups v1 before writing OOM file
- Use splice(2) to copy from stdin
* Thu Dec 12 2019 Sascha Grunert <sgrunert@suse.com>
- Kill the process group on timeout
* Wed Dec 11 2019 Sascha Grunert <sgrunert@suse.com>
- Add --persist-dir to allow callers to specify a directory that
  conmon should mirror certain important files that should persist
  reboots (right now, just the container exit file)
* Mon Dec  9 2019 Sascha Grunert <sgrunert@suse.com>
- Fix tight loop on OOM
* Thu Nov 14 2019 Sascha Grunert <sgrunert@suse.com>
- Add log level trace
- Separate handling of log reopen events and terminal resize events
* Tue Oct 29 2019 Sascha Grunert <sgrunert@suse.com>
- Add CONN_SOCK_BUF_SIZE to config
- Fix bug to close the sync pipe before exit command
* Mon Sep 16 2019 Sascha Grunert <sgrunert@suse.com>
- Set masterfd_stdout before registering ctrl_cb
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Upstream has an actual description, use it instead of just
  duplicating the summary again.
* Fri Aug 16 2019 Sascha Grunert <sgrunert@suse.com>
- Use `%%make_build` macro instead of `%%{__make}`
- Use `%%make_install` macro instead of `%%{__make} install`
- Use `%%{_bindir}` macro instead of `%%{_usr}/bin`
- Change `PREFIX` to not contain `%%{buildroot}` and use the
  `$DESTDIR` variable
* Mon Aug 12 2019 Sascha Grunert <sgrunert@suse.com>
- Initial release v2.0.0
